summaryrefslogtreecommitdiffstats
path: root/EmulatorPkg
diff options
context:
space:
mode:
Diffstat (limited to 'EmulatorPkg')
-rw-r--r--EmulatorPkg/PlatformCI/.azurepipelines/Windows-VS2019.yml6
-rw-r--r--EmulatorPkg/PlatformCI/PlatformBuild.py6
-rw-r--r--EmulatorPkg/PlatformCI/ReadMe.md2
-rw-r--r--EmulatorPkg/Readme.md8
4 files changed, 11 insertions, 11 deletions
diff --git a/EmulatorPkg/PlatformCI/.azurepipelines/Windows-VS2019.yml b/EmulatorPkg/PlatformCI/.azurepipelines/Windows-VS2019.yml
index 09960e7c7a..9e33ef136d 100644
--- a/EmulatorPkg/PlatformCI/.azurepipelines/Windows-VS2019.yml
+++ b/EmulatorPkg/PlatformCI/.azurepipelines/Windows-VS2019.yml
@@ -3,7 +3,7 @@
#
# Platform: EMULATORPKG
# OS: Windows
-# Toolchain: VS2019
+# Toolchain: VS2022
#
# Copyright (c) Microsoft Corporation.
# Copyright (c) 2020, Intel Corporation. All rights reserved.
@@ -23,7 +23,7 @@ jobs:
- job: Platform_CI
variables:
package: 'EmulatorPkg'
- vm_image: 'windows-2019'
+ vm_image: 'windows-2022'
should_run: true
run_flags: "MAKE_STARTUP_NSH=TRUE"
@@ -124,7 +124,7 @@ jobs:
steps:
- template: ../../../.azurepipelines/templates/platform-build-run-steps.yml
parameters:
- tool_chain_tag: VS2019
+ tool_chain_tag: VS2022
build_pkg: $(package)
build_target: $(Build.Target)
build_arch: $(Build.Arch)
diff --git a/EmulatorPkg/PlatformCI/ReadMe.md b/EmulatorPkg/PlatformCI/ReadMe.md
index f123bb2a48..00a8a3cd62 100644
--- a/EmulatorPkg/PlatformCI/ReadMe.md
+++ b/EmulatorPkg/PlatformCI/ReadMe.md
@@ -6,7 +6,7 @@ to use the same Pytools based build infrastructure locally.
## Supported Configuration Details
This solution for building and running EmulatorPkg has only been validated with Windows 10
-with VS2019 and Ubuntu 18.04 with GCC5 toolchain. Four different firmware builds are
+with VS2022 and Ubuntu 18.04 with GCC5 toolchain. Four different firmware builds are
supported and are described below.
| Configuration name | Architectures | DSC File |Additional Flags |
diff --git a/EmulatorPkg/Readme.md b/EmulatorPkg/Readme.md
index 0c2eea6a9a..2e6837ca4c 100644
--- a/EmulatorPkg/Readme.md
+++ b/EmulatorPkg/Readme.md
@@ -21,11 +21,11 @@ https://github.com/tianocore/tianocore.github.io/wiki/EmulatorPkg
**You can use the following command to build.**
* 32bit emulator in Windows:
- `build -p EmulatorPkg\EmulatorPkg.dsc -t VS2017 -a IA32`
+ `build -p EmulatorPkg\EmulatorPkg.dsc -t VS2022 -a IA32`
* 64bit emulator in Windows:
- `build -p EmulatorPkg\EmulatorPkg.dsc -t VS2017 -a X64`
+ `build -p EmulatorPkg\EmulatorPkg.dsc -t VS2022 -a X64`
* 32bit emulator in Linux:
@@ -38,11 +38,11 @@ https://github.com/tianocore/tianocore.github.io/wiki/EmulatorPkg
**You can start/run the emulator using the following command:**
* 32bit emulator in Windows:
- `cd Build\EmulatorIA32\DEBUG_VS2017\IA32\ && WinHost.exe`
+ `cd Build\EmulatorIA32\DEBUG_VS2022\IA32\ && WinHost.exe`
* 64bit emulator in Windows:
- `cd Build\EmulatorX64\DEBUG_VS2017\X64\ && WinHost.exe`
+ `cd Build\EmulatorX64\DEBUG_VS2022\X64\ && WinHost.exe`
* 32bit emulator in Linux:
diff --git a/EmulatorPkg/PlatformCI/PlatformBuild.py b/EmulatorPkg/PlatformCI/PlatformBuild.py
index 6defbf6ef1..aff01189a8 100644
--- a/EmulatorPkg/PlatformCI/PlatformBuild.py
+++ b/EmulatorPkg/PlatformCI/PlatformBuild.py
@@ -186,11 +186,11 @@ class PlatformBuilder(UefiBuilder, BuildSettingsManager):
def SetPlatformEnv(self):
logging.debug("PlatformBuilder SetPlatformEnv")
self.env.SetValue("PRODUCT_NAME", "EmulatorPkg", "Platform Hardcoded")
- self.env.SetValue("TOOL_CHAIN_TAG", "VS2019", "Default Toolchain")
+ self.env.SetValue("TOOL_CHAIN_TAG", "VS2022", "Default Toolchain")
# Add support for using the correct Platform Headers, tools, and Libs based on emulator architecture
- # requested to be built when building VS2019 or VS2017
- if self.env.GetValue("TOOL_CHAIN_TAG") == "VS2019" or self.env.GetValue("TOOL_CHAIN_TAG") == "VS2017":
+ # requested to be built when building VS2022 or VS2019
+ if self.env.GetValue("TOOL_CHAIN_TAG") == "VS2022" or self.env.GetValue("TOOL_CHAIN_TAG") == "VS2019":
key = self.env.GetValue("TOOL_CHAIN_TAG") + "_HOST"
if self.env.GetValue("TARGET_ARCH") == "IA32":
shell_environment.ShellEnvironment().set_shell_var(key, "x86")